@@ -1,5 +1,5 @@
 package Net::Google::Analytics;
-$Net::Google::Analytics::VERSION = '3.04';
+$Net::Google::Analytics::VERSION = '3.05';
 use strict;
 use warnings;
 
@@ -184,7 +184,7 @@ Net::Google::Analytics - Simple interface to the Google Analytics Core Reporting
 
 =head1 VERSION
 
-version 3.04
+version 3.05
 
 =head1 SYNOPSIS
 
@@ -194,6 +194,7 @@ version 3.04
     # Insert your numeric Analytics profile ID here. You can find it under
     # profile settings. DO NOT use your account or property ID (UA-nnnnnn).
     my $profile_id    = "1234567";
+
     # See GETTING STARTED for how to get a client id, client secret, and
     # refresh token
     my $client_id     = "123456789012.apps.googleusercontent.com";
@@ -252,19 +253,45 @@ Analytics Core Reporting API, Version 3.
 See L<http://code.google.com/apis/analytics/docs/gdata/home.html>
 for the complete API documentation.
 
-WARNING: This module is not API compatible with the 0.x releases which target
+B<WARNING:> This module is not API compatible with the 0.x releases which target
 the legacy v2 API.
 
 =head1 GETTING STARTED
 
-L<Net::Google::Analytics::OAuth2> provides for easy authentication and
-authorization using OAuth 2.0. First, you have to register your application
-through the L<Google APIs Console|https://code.google.com/apis/console/>.
+This module uses Google Analytics' API from a single Google User Account.
+This means you will need a Google account user that has (at least) read
+access to the Google Analytics profile you want to query. What we'll do
+is, through L<OAuth2|Net::Google::Analytics::OAuth2>, have that user
+grant Analytics access to your Perl app.
 
-You will receive a client id and a client secret for your application in the
-APIs Console. For command line testing, you should use "Installed application"
-as application type. Then you can obtain a refresh token for your application
-by running the following script with your client id and secret:
+First, you have to register your project through the
+L<Google Developers Console|https://console.developers.google.com/>.
+
+Next, on your project's API Manager page, go over to "credentials" and click
+on the "I<Create credentials>" button. When the drop down menu appears,
+click on "I<Help me choose>".
+
+=for html <p>
+<img src="https://raw.githubusercontent.com/nwellnhof/Net-Google-Analytics/master/doc_images/credentials-howto-1.png" alt="screenshot of Google's API Manager menu" />
+</p>
+
+Select "Analytics API" under "I<Which API are you using?>", and select
+"Other UI (CLI)" under "I<Where will you be calling the API from?>". Finally,
+when they ask you "I<What data will you be accessing?>", choose "User data".
+
+=for html <p>
+<img src="https://raw.githubusercontent.com/nwellnhof/Net-Google-Analytics/master/doc_images/credentials-howto-2.png" alt="screenshot of Google's API options" />
+</p>
+
+At the end of this process, you will receive a client id and a client
+secret for your application in the API Manager Console.
+
+The final step is to get a refresh token. This is required because OAuth
+access is granted only for a limited time, and the refresh token allows your
+app to renew that access whenever it needs.
+
+You can obtain a refresh token for your application by running the following
+script with your client id and secret:
 
     use Net::Google::Analytics::OAuth2;
 
@@ -281,10 +308,10 @@ be shown the code that you should enter in the Perl script. Then the script
 retrieves and prints a refresh token which can be used for non-interactive
 access.
 
-You also have to provide the profile ID of your Analytics profile with every
-request. You can find this decimal number hidden in the "profile settings"
-dialog in Google Analytics. Note that this ID is different from your account or
-property ID of the form UA-nnnnnn-n. Prepend your profile ID with "ga:" and
+You also have to provide the view ID (formerly profile ID) of your Analytics
+view with every request. You can find this decimal number under "Admin >
+View Settings" in Google Analytics. Note that this ID is different from your
+tracking ID of the form UA-nnnnnn-n. Prepend your view ID with "ga:" and
 pass it as "ids" parameter to the request object.
 
 The "ids", "metrics", "start_date", and "end_date" parameters are required for
@@ -364,7 +391,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
