@@ -1,5 +1,5 @@
 package Net::Google::Analytics::Response;
-$Net::Google::Analytics::Response::VERSION = '3.04';
+$Net::Google::Analytics::Response::VERSION = '3.05';
 use strict;
 use warnings;
 
@@ -67,7 +67,10 @@ sub _parse_column_name {
         or die("invalid column name: $name");
 
     # convert camel case
-    $res =~ s/[A-Z]/'_' . lc($&)/ge;
+    $res =~ s{([^A-Z]?)([A-Z]+)}{
+        my ($prev, $upper) = ($1, $2);
+        $prev . ($prev =~ /[a-z]/ ? '_' : '') . lc($upper);
+    }ge;
 
     return $res;
 }
@@ -187,7 +190,7 @@ Net::Google::Analytics::Response - Google Analytics API response
 
 =head1 VERSION
 
-version 3.04
+version 3.05
 
 =head1 SYNOPSIS
 
@@ -327,7 +330,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
