@@ -1,5 +1,5 @@
 package Net::Google::Analytics::Row;
-$Net::Google::Analytics::Row::VERSION = '3.04';
+$Net::Google::Analytics::Row::VERSION = '3.05';
 use strict;
 use warnings;
 
@@ -10,13 +10,19 @@ BEGIN {
 }
 
 my $class_count = 0;
+my %class_cache;
 
 # Dynamically generate a class with accessors
 sub _gen_class {
     my (undef, $column_headers) = @_;
 
+    # Cache lookup
+    my $cache_key = join("\t", map { $_->{name} } @$column_headers);
+    my $class = $class_cache{$cache_key};
+    return $class if $class;
+
     # Generate unique package name
-    my $class = "Net::Google::Analytics::Row_$class_count";
+    $class = "Net::Google::Analytics::Row_$class_count";
     ++$class_count;
 
     {
@@ -37,6 +43,9 @@ sub _gen_class {
         getters => \%getters,
     );
 
+    # Store in cache
+    $class_cache{$cache_key} = $class;
+
     return $class;
 }
 
@@ -78,7 +87,7 @@ Net::Google::Analytics::Row - Base class for Google Analytics API result rows
 
 =head1 VERSION
 
-version 3.04
+version 3.05
 
 =head1 DESCRIPTION
 
@@ -113,7 +122,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nick Wellnhofer.
+This software is copyright (c) 2016 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
